% Figure 5 for paper: A low-cost permeameter
% The mean effective flow resistivity for each foam type was derived from
% 'acoustic_fig_4.m'.
function [] = acoustic_fig_5()
mu = 1.65e-5; % air viscosity

blue = 1e4* [0.3972    0.3283    0.4971    0.7029    1.8723]; % blue
grey = 1e4* [0.3911    0.3250    0.3660    0.6561    1.5221]; % grey
red  = 1e4* [0.2736    0.2242    0.3288    0.5369    1.4345]; % red
permeability = 1e-6*[0.2060    0.1370    0.0470    0.0150    0.0030    0.0010];
fh = figure();
loglog(blue(2:end), permeability(2:5),'b*', 'MarkerSize', 15, 'LineWidth', 2);
hold on;
loglog(grey(2:end), permeability(2:5),'ko', 'MarkerSize', 15, 'LineWidth', 2);
loglog(red(2:end),  permeability(2:5),'r^', 'MarkerSize', 15, 'LineWidth', 2);
%[ slope_blue, y_intercept_blue, y_ret_blue ] = slope_intercept( blue, permeability(1:5) );
%[ slope_red, y_intercept_red, y_ret_red ] = slope_intercept( blue, permeability(1:5) );
%[ slope_grey, y_intercept_grey, y_ret_grey ] = slope_intercept( blue, permeability(1:5) );
xh = xlabel('Effective Flow Resistivity (Pa s m^{-2})');
yh = ylabel('Permeability (m^2)');
[ fitted_x_blue, fitted_y_blue, rsq_blue ] = fitted_line( log10(blue(2:5)), log10(permeability(2:5)));
[ fitted_x_grey, fitted_y_grey, rsq_grey ] = fitted_line( log10(grey(2:end)), log10(permeability(2:5)) );
[ fitted_x_red,  fitted_y_red, rsq_red ] = fitted_line( log10(red(2:end)), log10(permeability(2:5)) );

line(10.^fitted_x_blue, 10.^fitted_y_blue, 'Color', 'b', 'LineWidth', 2);
line(10.^fitted_x_grey, 10.^fitted_y_grey, 'Color', 'k', 'LineWidth', 2);
line(10.^fitted_x_red, 10.^fitted_y_red, 'Color', 'r', 'LineWidth', 2);

xlim([1e3 3e4]);
ylim([1e-9 3e-7]);

leg = legend('1.3V', '2.3V', '5.6V');

set_plot_attributes( fh, gca, '', xh, yh, '' );

heightScaleFactor = 1.5; % rescale legend height (after set_plot_attributes)
newHeight = leg.Position(4) * heightScaleFactor;
leg.Position(2) = leg.Position(2) - (newHeight - leg.Position(4));
leg.Position(4) = newHeight;

fprintf(1, 'R-squared blue: %f\n', rsq_blue);
fprintf(1, 'R-squared grey: %f\n', rsq_grey);
fprintf(1, 'R-squared red: %f\n', rsq_red);

% plot mean of 3 runs and find slope of the log ( = -2.17)
%ma = mean ([blue; grey; red]);
%plot(ma(2:end), permeability(2:5), 'm^', 'MarkerSize', 15)
%linearCoefficients = polyfit(log10(ma(2:end)), log10(permeability(2:5)), 1);

%{
fh = figure();
[ fitted_x_red,  fitted_y_red, rsq_red ] = fitted_line( log10(mu./red(2:end)), log10(permeability(2:5)) );
[s,y,yy]=slope_intercept(fitted_x_red, fitted_y_red)
loglog([1e-9 2e-7], [1e-9 2e-7], 'Color', 'k');
hold on;
kk = 10.^fitted_y_red;
ku = 3.1007 * 10.^(2.0217*fitted_x_red);
loglog(kk, ku, 'k.', 'MarkerSize', 30);
loglog(permeability(2:5), 1/0.4946.*mu./10.^fitted_x_red, 'k.', 'MarkerSize', 30);
%errorbar(permeability(2:5), mu./mean(sp(:,2:5)), mu./std(sp(:,2:5)), '.');
xlim([1e-9 2e-7]);
ylim([1e-9 2e-7]);
axis square;
%line([1e-9 2e-7], [1e-9 2e-7]);
xh = xlabel('Known Permeability (m^2)');
yh = ylabel('Computed Permeability (m^2)');
set_plot_attributes( fh, gca, '', xh, yh, '' );
%}
