function [ ] = acoustic_fig_7()
% Summary comparison of computed vs. known permeability
% red_m1 is the 500 Hz "red" data set for data acquisition method 1 
% m2 is the 50 Hz data set using data acquisition method 2

mu = 1.65e-5; % air viscosity
permeability = 1e-6*[0.206   0.1370    0.0470    0.0150    0.0030]; % Z10, Z20, Z30, Z50, Z80

% Calibrate effective flow resistivity to permeability. Calibrated permeability
% values taken from the end of acoustic_fig_4.m
red_m1_k_calib = 1e-6 .* [0.1086    0.0574    0.0177    0.0027; ...
                          0.1108    0.0454    0.0196    0.0026; ...
                          0.1163    0.0530    0.0203    0.0026];
red_m1_k_mean = mean(red_m1_k_calib);
red_m1_k_std  = std(red_m1_k_calib);
red_m1_error  = 100 .* abs(permeability(2:end) - red_m1_k_mean) ./ permeability(2:end);
fprintf(1, 'Mean normalized std: %f\n', 100 .* mean(red_m1_k_std)/mean(red_m1_k_mean));
fprintf(1, 'M1 %% error: %f\n', red_m1_error);
fprintf(1, 'Average M1 %% error: %f\n', mean(red_m1_error));

% IM method values at 50 Hz take from mic_timeseries_lab_lowf_1.m.
m2_k         = 1e-6* [0.2328    0.1425    0.0489    0.0151    0.0032; ...
                      0.2252    0.1348    0.0463    0.0150    0.0030; ...
                      0.1694    0.1340    0.0459    0.0150    0.0028];
%m2_k_mean    = mean(m2_k);
% Use values from curve fit in mic_timeseries_lab_lowf_1b
m2_k_mean = 1.0e-06 * [0.1809    0.1431    0.0568    0.0133    0.0031];
m2_k_std     = std(m2_k);
m2_error  = 100 .* abs(permeability(1:end) - m2_k_mean) ./ permeability(1:end);
fprintf(1, 'Mean normalized std: %f\n', 100 .* mean(m2_k_std)/mean(m2_k_mean));
fprintf(1, 'M2 %% error: %f\n', m2_error);
fprintf(1, 'Average M2 %% error: %f\n', mean(m2_error));

fh = figure();
loglog([1e-9 5e-7], [1e-9 5e-7], 'Color', 'k');
hold on;
he1=errorbar(permeability(2:end), red_m1_k_mean, red_m1_k_std, 'k.', 'MarkerSize', 15, 'LineWidth', 2);
he2=errorbar(permeability, m2_k_mean    , m2_k_std    , 'r.', 'MarkerSize', 15, 'LineWidth', 2);
leg = legend('Equality Line', 'EM Method', 'IM Method', 'Location', 'NorthWest');
xlim([1e-9 5e-7]);
ylim([1e-9 5e-7]);
axis square;

xh = xlabel('Known Permeability (m^2)');
yh = ylabel('Computed Permeability (m^2)');

txt(1) = text(1e-7, 2.0e-7, 'Z10');
txt(2) = text(6e-8, 1.2e-7, 'Z20');
txt(3) = text(2.2e-8, 5e-8, 'Z30');
txt(4) = text(7e-9, 1.7e-8, 'Z50');
txt(5) = text(1.4e-9, 2.8e-9, 'Z80');
set_plot_attributes( fh, gca, '', xh, yh, txt );

end

