function [ fitted_x, fitted_y, rsq, slope, intercept ] = fitted_line( x, y, co )
% Find a best fit line through the given points. Return points on this best
% fit line that preserves the original range (y-coordinate).

p = polyfit(x, y, 1);
% Get fitted values
slope = p(1);
intercept = p(2);

% Compute y-coordinate endpoints to be sure the fitted line has the same 
% range as the original data.
yfit =  p(1) * x + p(2);
x1 = (max(y)-p(2))/p(1);
x2 = (min(y)-p(2))/p(1);
y1 = p(1) * x1 + p(2);
y2 = p(1) * x2 + p(2);
fitted_x = [x1 x(2:end-1) x2];
fitted_y = [y1 yfit(2:end-1) y2];

%Compute the residual values as a vector of signed numbers:
yresid = y - fitted_y;

%Square the residuals and total them to obtain the residual sum of squares:
SSresid = sum(yresid.^2);

%Compute the total sum of squares of y by multiplying the variance of y by the number of observations minus 1:
SStotal = (length(y)-1) * var(y);

%Compute R2 using the formula given in the introduction of this topic:
rsq = 1 - SSresid/SStotal;

% Plot the fitted line
%hold on;
plot(fitted_x, fitted_y, 'MarkerEdgeColor', co, 'LineWidth', 1);


end

