function [ read_format, columns, startrow ] = get_spe_format( table_name )

% Return the data format for an SPE data file.
%
% INPUT PARAMETERS:
% datestring - the input date
%
% OUTPUT PARAMETERS:
% read_format  - string defining input file format
% columns      - number of columns
% startrow     - header length
%
% HISTORY:
% Steve Drake (12/28/2013)


if (strcmp(table_name, 'SPE_2014_Public.dat') )

    read_format = ['"%d-%d-%d %d:%d:%f",' ...          % date has 6 cols
    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...               % 10 cols
    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...               % 10 cols
    '%f,%f,%f,%f,%f,%f,%f,%f,%f\n'];                   % 9 cols and return
    columns = 34;
    startrow = 4;

elseif (strcmp(table_name, 'CR3000_ts_data.dat') )

    read_format = ['"%d-%d-%d %d:%d:%f",' ...          % date has 6 cols
          '%f,%f,%f,%f,%f\n'];                         % 5 cols and return
    columns = 11;
    startrow = 4;
    
elseif (strcmp(table_name, 'TOA5_CAPA.stats.dat') )

    read_format = ['"%d-%d-%d %d:%d:%f",' ...          % date has 6 cols
     '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...               % 10 cols
    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...               % 10 cols
    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...               % 10 cols
         '%f,%f,%f,%f,%f,%f,%f,%f,%f\n'];                         % 5 cols and return
    columns = 45;
    startrow = 4;

elseif (strcmp(table_name, 'CR1000_Table1.dat') )

    read_format = ['"%d-%d-%d %d:%d:%f",' ...          % date has 6 cols
    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...               % 10 cols
    '%f,%f,%f,%f,%f,%f,%f,%f\n'];                      % 8 cols and return
    columns = 24;
    startrow = 4;
    
elseif (strcmp(table_name, 'CR1000_Table1_Calib_T.dat') )

    read_format = ['"%d-%d-%d %d:%d:%f",' ...          % date has 6 cols
    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...               % 10 cols
    '%f,%f,%f,%f,%f,%f,%f,%f\n'];                      % 8 cols and return
    columns = 24;
    startrow = 4;
  
elseif (strcmp(table_name, 'CR1000_cmono_1.dat') || ...
        strcmp(table_name, 'CR1000_cmono_2.dat'))

    read_format = ['"%d-%d-%d %d:%d:%f",' ...          % date has 6 cols
    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...               % 10 cols
    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...               % 10 cols
    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...               % 10 cols
    '%f\n'];                   % 9 cols and return
    columns = 37;
    startrow = 4;
    
    elseif (strcmp(table_name, 'TOA5_OSU_Geosciences_Sta6.ts_data_irgason_2014_01_21_1229.dat') || ...
            strcmp(table_name, 'TOA5_OSU_Geosciences_Sta6.blah_blah.dat'))

    read_format = ['"%d-%d-%d %d:%d:%f",' ...          % date has 6 cols
    '%f,%f,%f,%f,%f,%f,%f,%f,%f\n'];                   % 9 cols and return
    columns = 15;
    startrow = 4;
    
    
    elseif (strcmp(table_name, 'TOA5_OSU_Geosciences_Sta6.slow_data_irgason.dat') || ...
            strcmp(table_name, 'TOA5_OSU_Geosciences_Sta6.stats.dat'))

    read_format = ['"%d-%d-%d %d:%d:%f",' ...          % date has 6 cols
                    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...              % 10 cols
                    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...
                    '%f\n'];               % 10 cols
    columns = 27;
    startrow = 4;
    
    % Irgason
    
    elseif (strcmp(table_name, 'CR1000_Irga_ts_data.dat')) % high frequency data

    read_format = ['"%d-%d-%d %d:%d:%f",' ...          % date has 6 cols
                    '%f,%f,%f,%f,%f,%f,%f,%f,%f\n'];               % 9 cols
    columns = 15;
    startrow = 4;
    
     elseif (strcmp(table_name, 'CR1000_Irga_stats.dat')) % minutely frequency data

    read_format = ['"%d-%d-%d %d:%d:%f",' ...          % date has 6 cols
                    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...
                    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...
                    '%f\n'];                              % 1 cols
    columns = 27;
    startrow = 4;
    
    
    % Pressure transducers
    elseif (strcmp(table_name, 'pt.dat'))

    read_format = ['"%d-%d-%d %d:%d:%f",' ...          % date has 6 cols
                    '%f,%f,%f,%f,%f\n'];               % 5 cols
    columns = 11;
    startrow = 4;
    
    % SPL radiation files
    elseif (strcmp(table_name, 'CO12201503090_par.csv') || ...
            strcmp(table_name, 'CO12201503280_par.csv')) % minutely frequency data

    read_format = ['%d,%d-%d-%d %d:%d:%d,' ... %  8 cols
                   '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...   % 10 cols
                   '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f' ...   % 10 cols
                   '\n'];                              % 1 cols
    columns = 27;
    startrow = 1;   
    % Oscilloscope files
    elseif (regexpi(table_name, 'F*.CSV'))
        
        read_format = ['%s,%s,%s,%s,%s,\n'];
        
    columns = 6;
    startrow = 18;
    
         elseif (strcmp(table_name, 'CSAT3_Irga_fast.dat')) % minutely frequency data

    read_format = ['"%d-%d-%d %d:%d:%f",' ...          % date has 6 cols
                    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...
                    '%f,%f,%f\n'];                              % 1 cols
    columns = 19;
    startrow = 4;
    
             elseif (strcmp(table_name, 'Irga_PT_20Hz.dat')) % minutely frequency data

    read_format = ['"%d-%d-%d %d:%d:%f",' ...          % date has 6 cols
                    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...
                    '%f,%f,%f\n'];                              % 1 cols
    columns = 19;
    startrow = 4;
    
    
             elseif (strcmp(table_name, 'Met_Tower_1min_all.dat') || ...
                     strcmp(table_name, 'Met_Tower_1min.dat')) % minutely frequency data

    read_format = ['"%d-%d-%d %d:%d:%f",' ...          % date has 6 cols
                    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...
                    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...
                    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...
                    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...
                    '%f,%f,%f,%f,%f,%f,%f,%f\n'];                              % 1 cols
    columns = 54;
    startrow = 4;
    
                 elseif (strcmp(table_name, 'Met_Tower_10sec.dat') || ...
                         strcmp(table_name, 'Met_Tower_10sec_all.dat')) % 10s frequency data

    read_format = ['"%d-%d-%d %d:%d:%f",' ...          % date has 6 cols
                    '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,' ...
                    '%f,%f,%f,%f,%f,%f\n'];                              % 6 cols
    columns = 22;
    startrow = 4;
    
                 elseif (strcmp(table_name, 'Met_Tower_20Hz.dat') || ...
                         strcmp(table_name, 'Met_Tower_20Hz_all.dat'))% 20 Hz frequency data

    read_format = ['"%d-%d-%d %d:%d:%f",%f,%f,%f,%f,%f\n'];                              % 1 cols
    columns = 11;
    startrow = 4;
    
                 elseif (strcmp(table_name, 'SPL_weather.dat')) % minutely frequency data

    read_format = ['%2d%2d%2d%2d%2d %f %f %f %f %f %f %f %f %f %f \n'];                              % 1 cols
    columns = 15;
    startrow = 5;
    
end

