function [run] = read_mic_timeseries_lab (rootdir, this_datestring, these_runs)
% Read in microphone data that was acquired with a Tektronics oscilloscope.

% rootdir = 'Permeameter_AC/'
% this_datestring = '20150921';
% Example: mic_timeseries_lab_3 (rootdir, this_datestring, [41 42 43 44 45 46 47 48 49 50 51 52])
% read_mic_timeseries (rootdir, this_datestring, [55 56 57 58 59 60 61 62 63 64 65 66])
% read_mic_timeseries (rootdir, this_datestring, [69 70 71 72 73 74 75 76 77 78 79 80])
% read_mic_timeseries (rootdir, this_datestring, [102 103 104 105 106 107])
% read_mic_timeseries (rootdir, this_datestring, [108 109 110 111 112 113 114 115 116 117 118])
% read_mic_timeseries (rootdir, this_datestring, [121 122 123 124 125 126 127 128 129 130 131 132 133])
% read_mic_timeseries (rootdir, this_datestring, [135 136 137 138 139 140 141 142 143 144 146 147 148])


for i = 1:length(these_runs)
    this_run = these_runs(i);
    file_ch1 = strcat('F', sprintf('%04d', this_run), 'CH1.CSV');
    file_ch2 = strcat('F', sprintf('%04d', this_run), 'CH2.CSV');
    
    dir_ch1 = fullfile(rootdir, this_datestring, strcat('ALL', file_ch1(2:5)));
    dir_ch2 = fullfile(rootdir ,this_datestring, strcat('ALL', file_ch2(2:5)));
    [ch1, header_1] = read_mic(dir_ch1, file_ch1);
    [ch2, header_2] = read_mic(dir_ch2, file_ch2);
    
    % Read an initialization file, date dependent.
    if (str2num(this_datestring) < 20151102)
    fprintf(1, 'Reading initialization from: signal_freq_lab()\n');
    [freq, this_rating, thickness] = signal_freq_lab(file_ch2);
    elseif (str2num(this_datestring) >= 20151102 && str2num(this_datestring) < 20151118)
        fprintf(1, 'Reading initialization from: signal_freq_lab2()\n');
        [freq, this_rating, thickness] = signal_freq_lab_2(file_ch2);
    elseif (str2num(this_datestring) >= 20151118 )
        fprintf(1, 'Reading initialization from: signal_freq_lab3()\n');
        [freq, this_rating, thickness] = signal_freq_lab_3(file_ch2);
    end
    % Strip off the vertical scale.
    this_line = header_1{9};
    asdf = strsplit(this_line, ',');
    ch1_v_scale = str2num(asdf{2});
    
    this_line = header_2{9};
    asdf = strsplit(this_line, ',');
    ch2_v_scale = str2num(asdf{2});
    
    
    % Save the input
    run(i).run_num = this_run;
    run(i).header_1 = header_1;
    run(i).header_2 = header_2;
    run(i).ch1_v_scale = ch1_v_scale;
    run(i).ch2_v_scale = ch2_v_scale;
    run(i).ch1 = ch1;
    run(i).ch2 = ch2;
    run(i).freq = freq;
    run(i).foam_rating = this_rating;
    run(i).thickness = thickness;
    run(i).permeability = permeability_rating(this_rating);
end
end


