function [ xp, yp, s ] = sine_fit( x, y, per )

% Fit a sine wave to data that may be noisy.
% 
% Input:
%   x   - the x-axis data (usually time)
%   y   - the signal amplitude
%   per - signal period, should be a close guess
%
% Output:
%   xp - best fit x-axis data, evenly spaced
%   yp - best fit y-axis data, evenly spaced
%   s(1): sine wave amplitude (in units of y)
%   s(2): period (in units of x)
%   s(3): phase (phase is s(2)/(s(3)) in units of x)
%   Note: the online doc said the following for phase but it is off by 2:
%         s(3): phase (phase is s(2)/(2*s(3)) in units of x)
%   s(4): offset (in units of y)
%
% History:
%   Steve Drake (2015) based on online docs

yu = max(y);                                % y maximum
yl = min(y);                                % y minimum
yr = (yu-yl);                               % Range of ?y?
yz = y-yu+(yr/2);                           % normalized to horiz axis
% does not work! zx = x(yz .* circshift(yz,[0 1]) <= 0);     % Find zero-crossings
% per = 2*mean(diff(zx));                   % Estimate period
ym = mean(y);                               % Estimate offset
fit = @(b,x)  b(1).*(sin(2*pi*x./b(2) + 2*pi/b(3))) + b(4);    % Function to fit
fcn = @(b) sum((fit(b,x) - y).^2);                              % Least-Squares cost function
s = fminsearch(fcn, [yr;  per;  -1;  ym]);                      % Minimize Least-Squares
xp = linspace(min(x),max(x));
yp = fit(s,xp);

%figure(1)
%plot(x,y,'b',  xp, yp, 'r')
%grid

end

